@@ -1,12 +1,13 @@
 <?php
+
+declare(strict_types=1);
+
 /**
  * This file is part of phpDocumentor.
  *
  *  For the full copyright and license information, please view the LICENSE
  *  file that was distributed with this source code.
  *
- *  @copyright 2010-2017 Mike van Riel<mike@phpdoc.org>
- *  @license   http://www.opensource.org/licenses/mit-license.php MIT
  *  @link      http://phpdoc.org
  */
 
@@ -23,12 +24,12 @@ final class DocblocksWithAnnotationsTest extends TestCase
     /**
      * Call Mockery::close after each test.
      */
-    public function tearDown()
+    public function tearDown(): void
     {
         m::close();
     }
 
-    public function testDocblockWithAnnotations()
+    public function testDocblockWithAnnotations(): void
     {
         $docComment = <<<DOCCOMMENT
             /**
@@ -38,13 +39,13 @@ final class DocblocksWithAnnotationsTest extends TestCase
      */
 DOCCOMMENT;
 
-        $factory  = DocBlockFactory::createInstance();
+        $factory = DocBlockFactory::createInstance();
         $docblock = $factory->create($docComment);
 
         $this->assertCount(3, $docblock->getTags());
     }
 
-    public function testDocblockWithAnnotationHavingZeroValue()
+    public function testDocblockWithAnnotationHavingZeroValue(): void
     {
         $docComment = <<<DOCCOMMENT
             /**
@@ -55,6 +56,6 @@ DOCCOMMENT;
         $factory = DocBlockFactory::createInstance();
         $docblock = $factory->create($docComment);
 
-        $this->assertSame(0, printf('%i', $docblock->getTagsByName('my-tag')));
+        $this->assertSame(0, (int) $docblock->getTagsByName('my-tag')[0]->render());
     }
 }
