@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace phpDocumentor\Reflection\DocBlock;
 
 use Mockery as m;
@@ -7,7 +9,7 @@ use phpDocumentor\Reflection\DocBlock\Tags\Example;
 use PHPUnit\Framework\TestCase;
 
 /**
- * @coversDefaultClass phpDocumentor\Reflection\DocBlock\ExampleFinder
+ * @coversDefaultClass \phpDocumentor\Reflection\DocBlock\ExampleFinder
  * @covers ::<private>
  */
 class ExampleFinderTest extends TestCase
@@ -18,25 +20,26 @@ class ExampleFinderTest extends TestCase
     /**
      * Call Mockery::close after each test.
      */
-    public function tearDown()
+    public function tearDown() : void
     {
         m::close();
     }
 
-    public function setUp()
+    public function setUp() : void
     {
         $this->fixture = new ExampleFinder();
     }
 
     /**
-     * @covers ::find
-     * @covers ::getSourceDirectory
      * @uses \phpDocumentor\Reflection\DocBlock\Tags\Example
      * @uses \phpDocumentor\Reflection\DocBlock\Description
+     *
+     * @covers ::find
+     * @covers ::getSourceDirectory
      */
-    public function testFileNotFound()
+    public function testFileNotFound() : void
     {
-        $example = new Example('./example.php', false, 1, 0, new Description('Test'));
+        $example = new Example('./example.php', false, 1, 0, 'Test');
         $this->assertSame('** File not found : ./example.php **', $this->fixture->find($example));
     }
 }
