@@ -1,12 +1,13 @@
 <?php
+
+declare(strict_types=1);
+
 /**
  * This file is part of phpDocumentor.
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  *
- * @copyright 2010-2015 Mike van Riel<mike@phpdoc.org>
- * @license   http://www.opensource.org/licenses/mit-license.php MIT
  * @link      http://phpdoc.org
  */
 
@@ -21,6 +22,7 @@ use phpDocumentor\Reflection\Types\Array_;
 use phpDocumentor\Reflection\Types\Compound;
 use phpDocumentor\Reflection\Types\Context;
 use phpDocumentor\Reflection\Types\Integer;
+use phpDocumentor\Reflection\Types\Mixed_;
 use phpDocumentor\Reflection\Types\Object_;
 use phpDocumentor\Reflection\Types\String_;
 use phpDocumentor\Reflection\Types\This;
@@ -36,16 +38,17 @@ class MethodTest extends TestCase
     /**
      * Call Mockery::close after each test.
      */
-    public function tearDown()
+    public function tearDown() : void
     {
         m::close();
     }
 
     /**
      * @uses   \phpDocumentor\Reflection\DocBlock\Tags\Method::__construct
+     *
      * @covers \phpDocumentor\Reflection\DocBlock\Tags\BaseTag::getName
      */
-    public function testIfCorrectTagNameIsReturned()
+    public function testIfCorrectTagNameIsReturned() : void
     {
         $fixture = new Method('myMethod');
 
@@ -58,16 +61,24 @@ class MethodTest extends TestCase
      * @uses   \phpDocumentor\Reflection\DocBlock\Tags\Method::__toString
      * @uses   \phpDocumentor\Reflection\DocBlock\Tags\Formatter\PassthroughFormatter
      * @uses   \phpDocumentor\Reflection\DocBlock\Description
+     *
      * @covers \phpDocumentor\Reflection\DocBlock\Tags\BaseTag::render
      * @covers \phpDocumentor\Reflection\DocBlock\Tags\BaseTag::getName
      */
-    public function testIfTagCanBeRenderedUsingDefaultFormatter()
+    public function testIfTagCanBeRenderedUsingDefaultFormatter() : void
     {
         $arguments = [
             ['name' => 'argument1', 'type' => new String_()],
-            ['name' => 'argument2', 'type' => new Object_()]
+            ['name' => 'argument2', 'type' => new Object_()],
         ];
-        $fixture = new Method('myMethod', $arguments, new Void_(), true, new Description('My Description'));
+
+        $fixture = new Method(
+            'myMethod',
+            $arguments,
+            new Void_(),
+            true,
+            new Description('My Description')
+        );
 
         $this->assertSame(
             '@method static void myMethod(string $argument1, object $argument2) My Description',
@@ -78,9 +89,10 @@ class MethodTest extends TestCase
     /**
      * @uses   \phpDocumentor\Reflection\DocBlock\Tags\Method::__construct
      * @uses   \phpDocumentor\Reflection\DocBlock\Description
+     *
      * @covers \phpDocumentor\Reflection\DocBlock\Tags\BaseTag::render
      */
-    public function testIfTagCanBeRenderedUsingSpecificFormatter()
+    public function testIfTagCanBeRenderedUsingSpecificFormatter() : void
     {
         $fixture = new Method('myMethod');
 
@@ -94,7 +106,7 @@ class MethodTest extends TestCase
      * @covers ::__construct
      * @covers ::getMethodName
      */
-    public function testHasMethodName()
+    public function testHasMethodName() : void
     {
         $expected = 'myMethod';
 
@@ -107,10 +119,10 @@ class MethodTest extends TestCase
      * @covers ::__construct
      * @covers ::getArguments
      */
-    public function testHasArguments()
+    public function testHasArguments() : void
     {
         $arguments = [
-            [ 'name' => 'argument1', 'type' => new String_() ]
+            ['name' => 'argument1', 'type' => new String_()],
         ];
 
         $fixture = new Method('myMethod', $arguments);
@@ -122,11 +134,11 @@ class MethodTest extends TestCase
      * @covers ::__construct
      * @covers ::getArguments
      */
-    public function testArgumentsMayBePassedAsString()
+    public function testArgumentsMayBePassedAsString() : void
     {
         $arguments = ['argument1'];
-        $expected = [
-            [ 'name' => $arguments[0], 'type' => new Void_() ]
+        $expected  = [
+            ['name' => $arguments[0], 'type' => new Mixed_()],
         ];
 
         $fixture = new Method('myMethod', $arguments);
@@ -138,11 +150,11 @@ class MethodTest extends TestCase
      * @covers ::__construct
      * @covers ::getArguments
      */
-    public function testArgumentTypeCanBeInferredAsVoid()
+    public function testArgumentTypeCanBeInferredAsMixed() : void
     {
-        $arguments = [ [ 'name' => 'argument1' ] ];
-        $expected = [
-            [ 'name' => $arguments[0]['name'], 'type' => new Void_() ]
+        $arguments = [['name' => 'argument1']];
+        $expected  = [
+            ['name' => $arguments[0]['name'], 'type' => new Mixed_()],
         ];
 
         $fixture = new Method('myMethod', $arguments);
@@ -151,23 +163,24 @@ class MethodTest extends TestCase
     }
 
     /**
-     * @covers ::create
      * @uses   \phpDocumentor\Reflection\DocBlock\Tags\Method::__construct
      * @uses   \phpDocumentor\Reflection\DocBlock\Tags\Method::getArguments
      * @uses   \phpDocumentor\Reflection\DocBlock\Description
+     *
+     * @covers ::create
      */
-    public function testRestArgumentIsParsedAsRegularArg()
+    public function testRestArgumentIsParsedAsRegularArg() : void
     {
         $expected = [
-            [ 'name' => 'arg1', 'type' => new Void_() ],
-            [ 'name' => 'rest', 'type' => new Void_() ],
-            [ 'name' => 'rest2', 'type' => new Array_() ],
+            ['name' => 'arg1', 'type' => new Mixed_()],
+            ['name' => 'rest', 'type' => new Mixed_()],
+            ['name' => 'rest2', 'type' => new Array_()],
         ];
 
         $descriptionFactory = m::mock(DescriptionFactory::class);
         $resolver           = new TypeResolver();
         $context            = new Context('');
-        $description  = new Description('');
+        $description        = new Description('');
         $descriptionFactory->shouldReceive('create')->with('', $context)->andReturn($description);
 
         $fixture = Method::create(
@@ -184,7 +197,7 @@ class MethodTest extends TestCase
      * @covers ::__construct
      * @covers ::getReturnType
      */
-    public function testHasReturnType()
+    public function testHasReturnType() : void
     {
         $expected = new String_();
 
@@ -197,7 +210,7 @@ class MethodTest extends TestCase
      * @covers ::__construct
      * @covers ::getReturnType
      */
-    public function testReturnTypeCanBeInferredAsVoid()
+    public function testReturnTypeCanBeInferredAsVoid() : void
     {
         $fixture = new Method('myMethod', []);
 
@@ -208,23 +221,24 @@ class MethodTest extends TestCase
      * @covers ::__construct
      * @covers ::isStatic
      */
-    public function testMethodCanBeStatic()
+    public function testMethodCanBeStatic() : void
     {
         $expected = false;
-        $fixture = new Method('myMethod', [], null, $expected);
+        $fixture  = new Method('myMethod', [], null, $expected);
         $this->assertSame($expected, $fixture->isStatic());
 
         $expected = true;
-        $fixture = new Method('myMethod', [], null, $expected);
+        $fixture  = new Method('myMethod', [], null, $expected);
         $this->assertSame($expected, $fixture->isStatic());
     }
 
     /**
+     * @uses   \phpDocumentor\Reflection\DocBlock\Description
+     *
      * @covers ::__construct
      * @covers \phpDocumentor\Reflection\DocBlock\Tags\BaseTag::getDescription
-     * @uses   \phpDocumentor\Reflection\DocBlock\Description
      */
-    public function testHasDescription()
+    public function testHasDescription() : void
     {
         $expected = new Description('Description');
 
@@ -234,47 +248,81 @@ class MethodTest extends TestCase
     }
 
     /**
-     * @covers ::__construct
-     * @covers ::__toString
      * @uses   \phpDocumentor\Reflection\DocBlock\Description
      * @uses   \phpDocumentor\Reflection\DocBlock\Tags\Method::isStatic
+     *
+     * @covers ::__construct
+     * @covers ::__toString
      */
-    public function testStringRepresentationIsReturned()
+    public function testStringRepresentationIsReturned() : void
     {
         $arguments = [
             ['name' => 'argument1', 'type' => new String_()],
-            ['name' => 'argument2', 'type' => new Object_()]
+            ['name' => 'argument2', 'type' => new Object_()],
         ];
-        $fixture = new Method('myMethod', $arguments, new Void_(), true, new Description('My Description'));
+        $fixture   = new Method('myMethod', $arguments, new Void_(), true, new Description('My Description'));
 
         $this->assertSame(
             'static void myMethod(string $argument1, object $argument2) My Description',
-            (string)$fixture
+            (string) $fixture
+        );
+    }
+
+    /**
+     * @uses   \phpDocumentor\Reflection\DocBlock\Description
+     * @uses   \phpDocumentor\Reflection\DocBlock\Tags\Method::isStatic
+     *
+     * @covers ::__construct
+     * @covers ::__toString
+     */
+    public function testStringRepresentationIsReturnedWithoutDescription() : void
+    {
+        $fixture = new Method('myMethod', [], null, false, new Description(''));
+
+        $this->assertSame(
+            'void myMethod()',
+            (string) $fixture
+        );
+
+        // ---
+
+        $arguments = [
+            ['name' => 'argument1', 'type' => new String_()],
+            ['name' => 'argument2', 'type' => new Object_()],
+        ];
+        $fixture   = new Method('myMethod', $arguments, new Void_(), true);
+
+        $this->assertSame(
+            'static void myMethod(string $argument1, object $argument2)',
+            (string) $fixture
         );
     }
 
     /**
-     * @covers ::create
      * @uses \phpDocumentor\Reflection\DocBlock\Tags\Method::<public>
      * @uses \phpDocumentor\Reflection\DocBlock\DescriptionFactory
      * @uses \phpDocumentor\Reflection\TypeResolver
      * @uses \phpDocumentor\Reflection\DocBlock\Description
      * @uses \phpDocumentor\Reflection\Fqsen
      * @uses \phpDocumentor\Reflection\Types\Context
+     *
+     * @covers ::create
      */
-    public function testFactoryMethod()
+    public function testFactoryMethod() : void
     {
         $descriptionFactory = m::mock(DescriptionFactory::class);
         $resolver           = new TypeResolver();
         $context            = new Context('');
 
-        $description  = new Description('My Description');
+        $description       = new Description('My Description');
         $expectedArguments = [
-            [ 'name' => 'argument1', 'type' => new String_() ],
-            [ 'name' => 'argument2', 'type' => new Void_() ]
+            ['name' => 'argument1', 'type' => new String_()],
+            ['name' => 'argument2', 'type' => new Mixed_()],
         ];
 
-        $descriptionFactory->shouldReceive('create')->with('My Description', $context)->andReturn($description);
+        $descriptionFactory->shouldReceive('create')
+            ->with('My Description', $context)
+            ->andReturn($description);
 
         $fixture = Method::create(
             'static void myMethod(string $argument1, $argument2) My Description',
@@ -283,7 +331,10 @@ class MethodTest extends TestCase
             $context
         );
 
-        $this->assertSame('static void myMethod(string $argument1, void $argument2) My Description', (string)$fixture);
+        $this->assertSame(
+            'static void myMethod(string $argument1, mixed $argument2) My Description',
+            (string) $fixture
+        );
         $this->assertSame('myMethod', $fixture->getMethodName());
         $this->assertEquals($expectedArguments, $fixture->getArguments());
         $this->assertInstanceOf(Void_::class, $fixture->getReturnType());
@@ -291,19 +342,20 @@ class MethodTest extends TestCase
     }
 
     /**
-     * @covers ::create
      * @uses \phpDocumentor\Reflection\DocBlock\Tags\Method::<public>
      * @uses \phpDocumentor\Reflection\TypeResolver
      * @uses \phpDocumentor\Reflection\DocBlock\Description
      * @uses \phpDocumentor\Reflection\Types\Context
+     *
+     * @covers ::create
      */
-    public function testReturnTypeThis()
+    public function testReturnTypeThis() : void
     {
         $descriptionFactory = m::mock(DescriptionFactory::class);
         $resolver           = new TypeResolver();
         $context            = new Context('');
 
-        $description  = new Description('');
+        $description = new Description('');
 
         $descriptionFactory->shouldReceive('create')->with('', $context)->andReturn($description);
 
@@ -315,156 +367,168 @@ class MethodTest extends TestCase
         );
 
         $this->assertTrue($fixture->isStatic());
-        $this->assertSame('static $this myMethod()', (string)$fixture);
+        $this->assertSame('static $this myMethod()', (string) $fixture);
         $this->assertSame('myMethod', $fixture->getMethodName());
         $this->assertInstanceOf(This::class, $fixture->getReturnType());
     }
 
-    public function collectionReturnTypesProvider()
+    /**
+     * @uses \phpDocumentor\Reflection\DocBlock\Tags\Method::<public>
+     * @uses \phpDocumentor\Reflection\TypeResolver
+     * @uses \phpDocumentor\Reflection\DocBlock\Description
+     * @uses \phpDocumentor\Reflection\Types\Context
+     *
+     * @covers ::create
+     */
+    public function testReturnTypeNoneWithLongMethodName() : void
+    {
+        $descriptionFactory = m::mock(DescriptionFactory::class);
+        $resolver           = new TypeResolver();
+        $context            = new Context('');
+
+        $description = new Description('');
+
+        $descriptionFactory->shouldReceive('create')->with('', $context)->andReturn($description);
+
+        $fixture = Method::create(
+            'myVeryLongMethodName($node)',
+            $resolver,
+            $descriptionFactory,
+            $context
+        );
+
+        $this->assertFalse($fixture->isStatic());
+        $this->assertSame('void myVeryLongMethodName(mixed $node)', (string) $fixture);
+        $this->assertSame('myVeryLongMethodName', $fixture->getMethodName());
+        $this->assertInstanceOf(Void_::class, $fixture->getReturnType());
+    }
+
+    /**
+     * @return string[][]
+     */
+    public function collectionReturnTypesProvider() : array
     {
         return [
-            ['int[]',    Array_::class, Integer::class, Compound::class],
-            ['int[][]',  Array_::class, Array_::class,  Compound::class],
+            ['int[]', Array_::class, Integer::class, Compound::class],
+            ['int[][]', Array_::class, Array_::class, Compound::class],
             ['Object[]', Array_::class, Object_::class, Compound::class],
-            ['array[]',  Array_::class, Array_::class,  Compound::class],
+            ['array[]', Array_::class, Array_::class, Compound::class],
         ];
     }
 
     /**
+     * @uses         \phpDocumentor\Reflection\DocBlock\Tags\Method::<public>
+     * @uses         \phpDocumentor\Reflection\DocBlock\Description
+     * @uses         \phpDocumentor\Reflection\DocBlock\DescriptionFactory
+     * @uses         \phpDocumentor\Reflection\TypeResolver
+     * @uses         \phpDocumentor\Reflection\Types\Array_
+     * @uses         \phpDocumentor\Reflection\Types\Compound
+     * @uses         \phpDocumentor\Reflection\Types\Integer
+     * @uses         \phpDocumentor\Reflection\Types\Object_
+     *
      * @dataProvider collectionReturnTypesProvider
      * @covers ::create
-     * @uses \phpDocumentor\Reflection\DocBlock\Tags\Method::<public>
-     * @uses \phpDocumentor\Reflection\DocBlock\Description
-     * @uses \phpDocumentor\Reflection\DocBlock\DescriptionFactory
-     * @uses \phpDocumentor\Reflection\TypeResolver
-     * @uses \phpDocumentor\Reflection\Types\Array_
-     * @uses \phpDocumentor\Reflection\Types\Compound
-     * @uses \phpDocumentor\Reflection\Types\Integer
-     * @uses \phpDocumentor\Reflection\Types\Object_
-     * @param string $returnType
-     * @param string $expectedType
-     * @param string $expectedValueType
-     * @param string null $expectedKeyType
      */
     public function testCollectionReturnTypes(
-        $returnType,
-        $expectedType,
-        $expectedValueType = null,
-        $expectedKeyType = null
-    ) {
+        string $returnType,
+        string $expectedType,
+        ?string $expectedValueType = null,
+        ?string $expectedKeyType = null
+    ) : void {
         $resolver           = new TypeResolver();
         $descriptionFactory = m::mock(DescriptionFactory::class);
-        $descriptionFactory->shouldReceive('create')->with('', null)->andReturn(new Description(''));
+        $descriptionFactory->shouldReceive('create')
+            ->with('', null)
+            ->andReturn(new Description(''));
 
-        $fixture = Method::create("$returnType myMethod(\$arg)", $resolver, $descriptionFactory);
+        $fixture    = Method::create("${returnType} myMethod(\$arg)", $resolver, $descriptionFactory);
         $returnType = $fixture->getReturnType();
         $this->assertInstanceOf($expectedType, $returnType);
 
-        if ($returnType instanceof Array_) {
-            $this->assertInstanceOf($expectedValueType, $returnType->getValueType());
-            $this->assertInstanceOf($expectedKeyType, $returnType->getKeyType());
+        if (!($returnType instanceof Array_)) {
+            return;
         }
+
+        $this->assertInstanceOf($expectedValueType, $returnType->getValueType());
+        $this->assertInstanceOf($expectedKeyType, $returnType->getKeyType());
     }
 
     /**
      * @covers ::create
-     * @expectedException \InvalidArgumentException
      */
-    public function testFactoryMethodFailsIfBodyIsNotString()
-    {
-        Method::create([]);
-    }
-
-    /**
-     * @covers ::create
-     * @expectedException \InvalidArgumentException
-     */
-    public function testFactoryMethodFailsIfBodyIsEmpty()
+    public function testFactoryMethodFailsIfBodyIsEmpty() : void
     {
+        $this->expectException('InvalidArgumentException');
         Method::create('');
     }
 
     /**
      * @covers ::create
-     * @expectedException \InvalidArgumentException
      */
-    public function testFactoryMethodReturnsNullIfBodyIsIncorrect()
+    public function testFactoryMethodReturnsNullIfBodyIsIncorrect() : void
     {
+        $this->expectException('InvalidArgumentException');
         $this->assertNull(Method::create('body('));
     }
 
     /**
      * @covers ::create
-     * @expectedException \InvalidArgumentException
      */
-    public function testFactoryMethodFailsIfResolverIsNull()
+    public function testFactoryMethodFailsIfResolverIsNull() : void
     {
+        $this->expectException('InvalidArgumentException');
         Method::create('body');
     }
 
     /**
      * @covers ::create
-     * @expectedException \InvalidArgumentException
      */
-    public function testFactoryMethodFailsIfDescriptionFactoryIsNull()
+    public function testFactoryMethodFailsIfDescriptionFactoryIsNull() : void
     {
+        $this->expectException('InvalidArgumentException');
         Method::create('body', new TypeResolver());
     }
 
     /**
      * @covers ::__construct
-     * @expectedException \InvalidArgumentException
      */
-    public function testCreationFailsIfBodyIsNotString()
-    {
-        new Method([]);
-    }
-
-    /**
-     * @covers ::__construct
-     * @expectedException \InvalidArgumentException
-     */
-    public function testCreationFailsIfBodyIsEmpty()
+    public function testCreationFailsIfBodyIsEmpty() : void
     {
+        $this->expectException('InvalidArgumentException');
         new Method('');
     }
 
     /**
      * @covers ::__construct
-     * @expectedException \InvalidArgumentException
      */
-    public function testCreationFailsIfStaticIsNotBoolean()
+    public function testCreationFailsIfArgumentRecordContainsInvalidEntry() : void
     {
-        new Method('body', [], null, []);
+        $this->expectException('InvalidArgumentException');
+        new Method('body', [['name' => 'myName', 'unknown' => 'nah']]);
     }
 
     /**
-     * @covers ::__construct
-     * @expectedException \InvalidArgumentException
-     */
-    public function testCreationFailsIfArgumentRecordContainsInvalidEntry()
-    {
-        new Method('body', [ [ 'name' => 'myName', 'unknown' => 'nah' ] ]);
-    }
-
-    /**
-     * @covers ::create
      * @uses \phpDocumentor\Reflection\DocBlock\Tags\Method::<public>
      * @uses \phpDocumentor\Reflection\DocBlock\DescriptionFactory
      * @uses \phpDocumentor\Reflection\TypeResolver
      * @uses \phpDocumentor\Reflection\DocBlock\Description
      * @uses \phpDocumentor\Reflection\Fqsen
      * @uses \phpDocumentor\Reflection\Types\Context
+     *
+     * @covers ::create
      */
-    public function testCreateMethodParenthesisMissing()
+    public function testCreateMethodParenthesisMissing() : void
     {
         $descriptionFactory = m::mock(DescriptionFactory::class);
         $resolver           = new TypeResolver();
         $context            = new Context('');
 
-        $description  = new Description('My Description');
+        $description = new Description('My Description');
 
-        $descriptionFactory->shouldReceive('create')->with('My Description', $context)->andReturn($description);
+        $descriptionFactory->shouldReceive('create')->with(
+            'My Description',
+            $context
+        )->andReturn($description);
 
         $fixture = Method::create(
             'static void myMethod My Description',
@@ -473,7 +537,7 @@ class MethodTest extends TestCase
             $context
         );
 
-        $this->assertSame('static void myMethod() My Description', (string)$fixture);
+        $this->assertSame('static void myMethod() My Description', (string) $fixture);
         $this->assertSame('myMethod', $fixture->getMethodName());
         $this->assertEquals([], $fixture->getArguments());
         $this->assertInstanceOf(Void_::class, $fixture->getReturnType());
@@ -481,7 +545,6 @@ class MethodTest extends TestCase
     }
 
     /**
-     * @covers ::create
      * @uses \phpDocumentor\Reflection\DocBlock\Tags\Method::<public>
      * @uses \phpDocumentor\Reflection\DocBlock\DescriptionFactory
      * @uses \phpDocumentor\Reflection\TypeResolver
@@ -499,7 +562,9 @@ class MethodTest extends TestCase
 
         $description = new Description('My Description');
 
-        $descriptionFactory->shouldReceive('create')->with('My Description', $context)->andReturn($description);
+        $descriptionFactory->shouldReceive('create')
+            ->with('My Description', $context)
+            ->andReturn($description);
 
         $fixture = Method::create(
             'static void myMethod() My Description',
@@ -523,14 +588,16 @@ class MethodTest extends TestCase
      * @uses \phpDocumentor\Reflection\Fqsen
      * @uses \phpDocumentor\Reflection\Types\Context
      * @uses \phpDocumentor\Reflection\Types\Void_
+     *
+     * @covers ::create
      */
-    public function testCreateWithoutReturnType()
+    public function testCreateWithoutReturnType() : void
     {
         $descriptionFactory = m::mock(DescriptionFactory::class);
         $resolver           = new TypeResolver();
         $context            = new Context('');
 
-        $description  = new Description('');
+        $description = new Description('');
 
         $descriptionFactory->shouldReceive('create')->with('', $context)->andReturn($description);
 
@@ -541,7 +608,7 @@ class MethodTest extends TestCase
             $context
         );
 
-        $this->assertSame('void myMethod()', (string)$fixture);
+        $this->assertSame('void myMethod()', (string) $fixture);
         $this->assertSame('myMethod', $fixture->getMethodName());
         $this->assertEquals([], $fixture->getArguments());
         $this->assertInstanceOf(Void_::class, $fixture->getReturnType());
@@ -549,7 +616,6 @@ class MethodTest extends TestCase
     }
 
     /**
-     * @covers ::create
      * @uses \phpDocumentor\Reflection\DocBlock\Tags\Method::<public>
      * @uses \phpDocumentor\Reflection\DocBlock\DescriptionFactory
      * @uses \phpDocumentor\Reflection\TypeResolver
@@ -560,8 +626,10 @@ class MethodTest extends TestCase
      * @uses \phpDocumentor\Reflection\Types\Compound
      * @uses \phpDocumentor\Reflection\Types\Integer
      * @uses \phpDocumentor\Reflection\Types\Object_
+     *
+     * @covers ::create
      */
-    public function testCreateWithMixedReturnTypes()
+    public function testCreateWithMixedReturnTypes() : void
     {
         $descriptionFactory = m::mock(DescriptionFactory::class);
         $resolver           = new TypeResolver();
@@ -576,7 +644,7 @@ class MethodTest extends TestCase
             $context
         );
 
-        $this->assertSame('\MyClass[]|int[] myMethod()', (string)$fixture);
+        $this->assertSame('\MyClass[]|int[] myMethod()', (string) $fixture);
         $this->assertSame('myMethod', $fixture->getMethodName());
         $this->assertEquals([], $fixture->getArguments());
 
